<?php

namespace Drupal\available_translation\Plugin\Block;

use Drupal\available_translation\Service\AvailableTranslationService;
use Drupal\Core\Access\AccessResult;
use Drupal\Core\Block\BlockBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Session\AccountInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides an Available Translation block.
 *
 * @Block(
 *   id = "available_translation",
 *   admin_label = @Translation("Available Translation"),
 *   category = @Translation("Menus")
 * )
 */
class AvailableTranslationBlock extends BlockBase implements ContainerFactoryPluginInterface {
  /**
   * @var AvailableTranslationService
   */
  protected $service;

  /**
   * AvailableTranslationBlock constructor.
   * @param array $configuration
   * @param $plugin_id
   * @param $plugin_definition
   * @param AvailableTranslationService $service
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, AvailableTranslationService $service) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->service = $service;
  }

  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('available_translation.service')
    );
  }

  public function defaultConfiguration() {
    return [
      'delimiter' => ' | ',
      'position' => 'left'
    ];
  }

  public function blockForm($form, FormStateInterface $form_state) {
    $form = parent::blockForm($form, $form_state);

    $config = $this->getConfiguration();
    $default_config = $this->defaultConfiguration();

    $form['delimiter'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Delimiter'),
      '#description' => $this->t('Example: " | " for "Armenian | English | French"'),
      '#default_value' => $config['delimiter'] ?? $default_config['delimiter'],
    ];

    $form['position'] = [
      '#type' => 'radios',
      '#title' => $this->t('Position'),
      '#options' => [
        'left' => $this->t("Left"),
        'right' => $this->t("Right")
      ],
      '#default_value' => $config['position'] ?? $default_config['position'],
    ];

    return $form;
  }

  public function blockSubmit($form, FormStateInterface $form_state) {
    parent::blockSubmit($form, $form_state);
    $values = $form_state->getValues();
    $this->setConfiguration([
      'delimiter' => $values['delimiter'],
      'position' => $values['position']
    ]);
  }

  public function build() {
    $config = $this->getConfiguration();
    $output = $this->service->getContent($config['delimiter']);
    $output = $output ? $this->t("Available in: ") . $output : $this->t("No translattion available!");
    return [
      '#theme' => 'available_translation_template',
      '#text' => $output,
      '#position' => $config['position'],
      '#attached' => [
        'library' => ['available_translation/available_translation'],
      ],
      '#cache' => [
        'max-age' => 0,
      ]
    ];
  }

  protected function blockAccess(AccountInterface $account) {
    if (!$account->hasPermission("access available_translation links")) {
      return AccessResult::forbidden();
    }
    return parent::blockAccess($account);
  }
}
